# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.kms.v1 import symmetric_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2
from yandex.cloud.kms.v1 import symmetric_key_service_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class SymmetricKeyServiceStub(object):
    """Set of methods for managing symmetric KMS keys.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/Create',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CreateSymmetricKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/Get',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.GetSymmetricKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2.SymmetricKey.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/List',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysResponse.FromString,
                )
        self.ListVersions = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/ListVersions',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/Update',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.UpdateSymmetricKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/Delete',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.DeleteSymmetricKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.SetPrimaryVersion = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/SetPrimaryVersion',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.SetPrimarySymmetricKeyVersionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ScheduleVersionDestruction = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/ScheduleVersionDestruction',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ScheduleSymmetricKeyVersionDestructionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.CancelVersionDestruction = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/CancelVersionDestruction',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CancelSymmetricKeyVersionDestructionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Rotate = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/Rotate',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.RotateSymmetricKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricKeyService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class SymmetricKeyServiceServicer(object):
    """Set of methods for managing symmetric KMS keys.
    """

    def Create(self, request, context):
        """--- control plane

        Creates a symmetric KMS key in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified symmetric KMS key.

        To get the list of available symmetric KMS keys, make a [SymmetricKeyService.List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Returns the list of symmetric KMS keys in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVersions(self, request, context):
        """Returns the list of versions of the specified symmetric KMS key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified symmetric KMS key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified symmetric KMS key. This action also automatically schedules
        the destruction of all of the key's versions in 72 hours.

        The key and its versions appear absent in [SymmetricKeyService.Get] and [SymmetricKeyService.List]
        requests, but can be restored within 72 hours with a request to tech support.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPrimaryVersion(self, request, context):
        """Sets the primary version for the specified key. The primary version is used
        by default for all encrypt/decrypt operations where no version ID is specified.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleVersionDestruction(self, request, context):
        """Schedules the specified key version for destruction.

        Scheduled destruction can be cancelled with the [SymmetricKeyService.CancelVersionDestruction] method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelVersionDestruction(self, request, context):
        """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rotate(self, request, context):
        """Rotates the specified key: creates a new key version and makes it the primary version.
        The old version remains available for decryption of ciphertext encrypted with it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified symmetric KMS key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists existing access bindings for the specified key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SymmetricKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CreateSymmetricKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.GetSymmetricKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2.SymmetricKey.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysResponse.SerializeToString,
            ),
            'ListVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVersions,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.UpdateSymmetricKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.DeleteSymmetricKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetPrimaryVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPrimaryVersion,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.SetPrimarySymmetricKeyVersionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ScheduleVersionDestruction': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleVersionDestruction,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ScheduleSymmetricKeyVersionDestructionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'CancelVersionDestruction': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelVersionDestruction,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CancelSymmetricKeyVersionDestructionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Rotate': grpc.unary_unary_rpc_method_handler(
                    servicer.Rotate,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.RotateSymmetricKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.kms.v1.SymmetricKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SymmetricKeyService(object):
    """Set of methods for managing symmetric KMS keys.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/Create',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CreateSymmetricKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/Get',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.GetSymmetricKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2.SymmetricKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/List',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/ListVersions',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/Update',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.UpdateSymmetricKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/Delete',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.DeleteSymmetricKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPrimaryVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/SetPrimaryVersion',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.SetPrimarySymmetricKeyVersionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScheduleVersionDestruction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/ScheduleVersionDestruction',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ScheduleSymmetricKeyVersionDestructionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelVersionDestruction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/CancelVersionDestruction',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.CancelSymmetricKeyVersionDestructionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Rotate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/Rotate',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.RotateSymmetricKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/ListOperations',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__service__pb2.ListSymmetricKeyOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.SymmetricKeyService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/k8s/v1/node.proto',
  package='yandex.cloud.k8s.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eyandex/cloud/k8s/v1/node.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xc7\x05\n\x04Node\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32 .yandex.cloud.k8s.v1.Node.Status\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.yandex.cloud.k8s.v1.Node.Spec\x12;\n\x0c\x63loud_status\x18\x03 \x01(\x0b\x32%.yandex.cloud.k8s.v1.Node.CloudStatus\x12\x45\n\x11kubernetes_status\x18\x04 \x01(\x0b\x32*.yandex.cloud.k8s.v1.Node.KubernetesStatus\x1a\xbd\x01\n\x10KubernetesStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\nconditions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.k8s.v1.Condition\x12*\n\x06taints\x18\x03 \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12=\n\x10\x61ttached_volumes\x18\x04 \x03(\x0b\x32#.yandex.cloud.k8s.v1.AttachedVolume\x1a\x41\n\x0b\x43loudStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x16\n\x0estatus_message\x18\x03 \x01(\t\x1aj\n\x04Spec\x12\x35\n\tresources\x18\x01 \x01(\x0b\x32\".yandex.cloud.k8s.v1.ResourcesSpec\x12+\n\x04\x64isk\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.k8s.v1.DiskSpec\"l\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x11\n\rNOT_CONNECTED\x10\x02\x12\r\n\tNOT_READY\x10\x03\x12\t\n\x05READY\x10\x04\x12\x0b\n\x07MISSING\x10\x05\"\xad\x01\n\tCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x37\n\x13last_heartbeat_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14last_transition_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb1\x01\n\x05Taint\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x31\n\x06\x65\x66\x66\x65\x63t\x18\x03 \x01(\x0e\x32!.yandex.cloud.k8s.v1.Taint.Effect\"Y\n\x06\x45\x66\x66\x65\x63t\x12\x16\n\x12\x45\x46\x46\x45\x43T_UNSPECIFIED\x10\x00\x12\x0f\n\x0bNO_SCHEDULE\x10\x01\x12\x16\n\x12PREFER_NO_SCHEDULE\x10\x02\x12\x0e\n\nNO_EXECUTE\x10\x03\"<\n\x0e\x41ttachedVolume\x12\x13\n\x0b\x64river_name\x18\x01 \x01(\t\x12\x15\n\rvolume_handle\x18\x02 \x01(\t\"\xc4\x06\n\x0cNodeTemplate\x12\x13\n\x0bplatform_id\x18\x01 \x01(\t\x12:\n\x0eresources_spec\x18\x02 \x01(\x0b\x32\".yandex.cloud.k8s.v1.ResourcesSpec\x12\x35\n\x0e\x62oot_disk_spec\x18\x03 \x01(\x0b\x32\x1d.yandex.cloud.k8s.v1.DiskSpec\x12w\n\x08metadata\x18\x04 \x03(\x0b\x32/.yandex.cloud.k8s.v1.NodeTemplate.MetadataEntryB4\x82\xc8\x31\x04<=64\x8a\xc8\x31\x08<=131072\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x41\n\x0fv4_address_spec\x18\x05 \x01(\x0b\x32$.yandex.cloud.k8s.v1.NodeAddressSpecB\x02\x18\x01\x12@\n\x11scheduling_policy\x18\x06 \x01(\x0b\x32%.yandex.cloud.k8s.v1.SchedulingPolicy\x12J\n\x17network_interface_specs\x18\x07 \x03(\x0b\x32).yandex.cloud.k8s.v1.NetworkInterfaceSpec\x12>\n\x10placement_policy\x18\n \x01(\x0b\x32$.yandex.cloud.k8s.v1.PlacementPolicy\x12K\n\x10network_settings\x18\x0b \x01(\x0b\x32\x31.yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xa3\x01\n\x0fNetworkSettings\x12J\n\x04type\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings.TypeB\x04\xe8\xc7\x31\x01\"D\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x18\n\x14SOFTWARE_ACCELERATED\x10\x02\"\xd4\x01\n\x14NetworkInterfaceSpec\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12\x45\n\x17primary_v4_address_spec\x18\x03 \x01(\x0b\x32$.yandex.cloud.k8s.v1.NodeAddressSpec\x12\x45\n\x17primary_v6_address_spec\x18\x04 \x01(\x0b\x32$.yandex.cloud.k8s.v1.NodeAddressSpec\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\"T\n\x0fNodeAddressSpec\x12\x41\n\x13one_to_one_nat_spec\x18\x01 \x01(\x0b\x32$.yandex.cloud.k8s.v1.OneToOneNatSpec\"E\n\x0fOneToOneNatSpec\x12\x32\n\nip_version\x18\x01 \x01(\x0e\x32\x1e.yandex.cloud.k8s.v1.IpVersion\"y\n\rResourcesSpec\x12\x17\n\x06memory\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x16\n\x05\x63ores\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12 \n\rcore_fraction\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x15\n\x04gpus\x18\x04 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\"\x80\x01\n\x08\x44iskSpec\x12L\n\x0c\x64isk_type_id\x18\x01 \x01(\tB6\xf2\xc7\x31\x32|network-ssd|network-hdd|network-ssd-nonreplicated\x12&\n\tdisk_size\x18\x02 \x01(\x03\x42\x13\xfa\xc7\x31\x0f\x30-4398046511104\"\'\n\x10SchedulingPolicy\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"-\n\x0fPlacementPolicy\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02\x42V\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_IPVERSION = _descriptor.EnumDescriptor(
  name='IpVersion',
  full_name='yandex.cloud.k8s.v1.IpVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IP_VERSION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IPV4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IPV6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2804,
  serialized_end=2863,
)
_sym_db.RegisterEnumDescriptor(_IPVERSION)

IpVersion = enum_type_wrapper.EnumTypeWrapper(_IPVERSION)
IP_VERSION_UNSPECIFIED = 0
IPV4 = 1
IPV6 = 2


_NODE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.k8s.v1.Node.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVISIONING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_CONNECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=723,
  serialized_end=831,
)
_sym_db.RegisterEnumDescriptor(_NODE_STATUS)

_TAINT_EFFECT = _descriptor.EnumDescriptor(
  name='Effect',
  full_name='yandex.cloud.k8s.v1.Taint.Effect',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EFFECT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_SCHEDULE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREFER_NO_SCHEDULE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_EXECUTE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1098,
  serialized_end=1187,
)
_sym_db.RegisterEnumDescriptor(_TAINT_EFFECT)

_NODETEMPLATE_NETWORKSETTINGS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STANDARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOFTWARE_ACCELERATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2020,
  serialized_end=2088,
)
_sym_db.RegisterEnumDescriptor(_NODETEMPLATE_NETWORKSETTINGS_TYPE)


_NODE_KUBERNETESSTATUS = _descriptor.Descriptor(
  name='KubernetesStatus',
  full_name='yandex.cloud.k8s.v1.Node.KubernetesStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.k8s.v1.Node.KubernetesStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='yandex.cloud.k8s.v1.Node.KubernetesStatus.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taints', full_name='yandex.cloud.k8s.v1.Node.KubernetesStatus.taints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_volumes', full_name='yandex.cloud.k8s.v1.Node.KubernetesStatus.attached_volumes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=546,
)

_NODE_CLOUDSTATUS = _descriptor.Descriptor(
  name='CloudStatus',
  full_name='yandex.cloud.k8s.v1.Node.CloudStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.k8s.v1.Node.CloudStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.k8s.v1.Node.CloudStatus.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_message', full_name='yandex.cloud.k8s.v1.Node.CloudStatus.status_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=613,
)

_NODE_SPEC = _descriptor.Descriptor(
  name='Spec',
  full_name='yandex.cloud.k8s.v1.Node.Spec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.k8s.v1.Node.Spec.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk', full_name='yandex.cloud.k8s.v1.Node.Spec.disk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=721,
)

_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='yandex.cloud.k8s.v1.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.k8s.v1.Node.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yandex.cloud.k8s.v1.Node.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud_status', full_name='yandex.cloud.k8s.v1.Node.cloud_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubernetes_status', full_name='yandex.cloud.k8s.v1.Node.kubernetes_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODE_KUBERNETESSTATUS, _NODE_CLOUDSTATUS, _NODE_SPEC, ],
  enum_types=[
    _NODE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=831,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='yandex.cloud.k8s.v1.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.k8s.v1.Condition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.k8s.v1.Condition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='yandex.cloud.k8s.v1.Condition.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_heartbeat_time', full_name='yandex.cloud.k8s.v1.Condition.last_heartbeat_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_transition_time', full_name='yandex.cloud.k8s.v1.Condition.last_transition_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=1007,
)


_TAINT = _descriptor.Descriptor(
  name='Taint',
  full_name='yandex.cloud.k8s.v1.Taint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.Taint.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.Taint.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effect', full_name='yandex.cloud.k8s.v1.Taint.effect', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TAINT_EFFECT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1010,
  serialized_end=1187,
)


_ATTACHEDVOLUME = _descriptor.Descriptor(
  name='AttachedVolume',
  full_name='yandex.cloud.k8s.v1.AttachedVolume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver_name', full_name='yandex.cloud.k8s.v1.AttachedVolume.driver_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_handle', full_name='yandex.cloud.k8s.v1.AttachedVolume.volume_handle', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1189,
  serialized_end=1249,
)


_NODETEMPLATE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yandex.cloud.k8s.v1.NodeTemplate.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.NodeTemplate.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.NodeTemplate.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1922,
)

_NODETEMPLATE_NETWORKSETTINGS = _descriptor.Descriptor(
  name='NetworkSettings',
  full_name='yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NODETEMPLATE_NETWORKSETTINGS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=2088,
)

_NODETEMPLATE = _descriptor.Descriptor(
  name='NodeTemplate',
  full_name='yandex.cloud.k8s.v1.NodeTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='platform_id', full_name='yandex.cloud.k8s.v1.NodeTemplate.platform_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_spec', full_name='yandex.cloud.k8s.v1.NodeTemplate.resources_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boot_disk_spec', full_name='yandex.cloud.k8s.v1.NodeTemplate.boot_disk_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.k8s.v1.NodeTemplate.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\010<=131072\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_address_spec', full_name='yandex.cloud.k8s.v1.NodeTemplate.v4_address_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduling_policy', full_name='yandex.cloud.k8s.v1.NodeTemplate.scheduling_policy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_specs', full_name='yandex.cloud.k8s.v1.NodeTemplate.network_interface_specs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_policy', full_name='yandex.cloud.k8s.v1.NodeTemplate.placement_policy', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_settings', full_name='yandex.cloud.k8s.v1.NodeTemplate.network_settings', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODETEMPLATE_METADATAENTRY, _NODETEMPLATE_NETWORKSETTINGS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=2088,
)


_NETWORKINTERFACESPEC = _descriptor.Descriptor(
  name='NetworkInterfaceSpec',
  full_name='yandex.cloud.k8s.v1.NetworkInterfaceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.k8s.v1.NetworkInterfaceSpec.subnet_ids', index=0,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v4_address_spec', full_name='yandex.cloud.k8s.v1.NetworkInterfaceSpec.primary_v4_address_spec', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v6_address_spec', full_name='yandex.cloud.k8s.v1.NetworkInterfaceSpec.primary_v6_address_spec', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.k8s.v1.NetworkInterfaceSpec.security_group_ids', index=3,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2303,
)


_NODEADDRESSSPEC = _descriptor.Descriptor(
  name='NodeAddressSpec',
  full_name='yandex.cloud.k8s.v1.NodeAddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='one_to_one_nat_spec', full_name='yandex.cloud.k8s.v1.NodeAddressSpec.one_to_one_nat_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2305,
  serialized_end=2389,
)


_ONETOONENATSPEC = _descriptor.Descriptor(
  name='OneToOneNatSpec',
  full_name='yandex.cloud.k8s.v1.OneToOneNatSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_version', full_name='yandex.cloud.k8s.v1.OneToOneNatSpec.ip_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2391,
  serialized_end=2460,
)


_RESOURCESSPEC = _descriptor.Descriptor(
  name='ResourcesSpec',
  full_name='yandex.cloud.k8s.v1.ResourcesSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory', full_name='yandex.cloud.k8s.v1.ResourcesSpec.memory', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cores', full_name='yandex.cloud.k8s.v1.ResourcesSpec.cores', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='core_fraction', full_name='yandex.cloud.k8s.v1.ResourcesSpec.core_fraction', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpus', full_name='yandex.cloud.k8s.v1.ResourcesSpec.gpus', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2462,
  serialized_end=2583,
)


_DISKSPEC = _descriptor.Descriptor(
  name='DiskSpec',
  full_name='yandex.cloud.k8s.v1.DiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_type_id', full_name='yandex.cloud.k8s.v1.DiskSpec.disk_type_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\30712|network-ssd|network-hdd|network-ssd-nonreplicated', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_size', full_name='yandex.cloud.k8s.v1.DiskSpec.disk_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0170-4398046511104', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2586,
  serialized_end=2714,
)


_SCHEDULINGPOLICY = _descriptor.Descriptor(
  name='SchedulingPolicy',
  full_name='yandex.cloud.k8s.v1.SchedulingPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preemptible', full_name='yandex.cloud.k8s.v1.SchedulingPolicy.preemptible', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2716,
  serialized_end=2755,
)


_PLACEMENTPOLICY = _descriptor.Descriptor(
  name='PlacementPolicy',
  full_name='yandex.cloud.k8s.v1.PlacementPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.k8s.v1.PlacementPolicy.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2757,
  serialized_end=2802,
)

_NODE_KUBERNETESSTATUS.fields_by_name['conditions'].message_type = _CONDITION
_NODE_KUBERNETESSTATUS.fields_by_name['taints'].message_type = _TAINT
_NODE_KUBERNETESSTATUS.fields_by_name['attached_volumes'].message_type = _ATTACHEDVOLUME
_NODE_KUBERNETESSTATUS.containing_type = _NODE
_NODE_CLOUDSTATUS.containing_type = _NODE
_NODE_SPEC.fields_by_name['resources'].message_type = _RESOURCESSPEC
_NODE_SPEC.fields_by_name['disk'].message_type = _DISKSPEC
_NODE_SPEC.containing_type = _NODE
_NODE.fields_by_name['status'].enum_type = _NODE_STATUS
_NODE.fields_by_name['spec'].message_type = _NODE_SPEC
_NODE.fields_by_name['cloud_status'].message_type = _NODE_CLOUDSTATUS
_NODE.fields_by_name['kubernetes_status'].message_type = _NODE_KUBERNETESSTATUS
_NODE_STATUS.containing_type = _NODE
_CONDITION.fields_by_name['last_heartbeat_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONDITION.fields_by_name['last_transition_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TAINT.fields_by_name['effect'].enum_type = _TAINT_EFFECT
_TAINT_EFFECT.containing_type = _TAINT
_NODETEMPLATE_METADATAENTRY.containing_type = _NODETEMPLATE
_NODETEMPLATE_NETWORKSETTINGS.fields_by_name['type'].enum_type = _NODETEMPLATE_NETWORKSETTINGS_TYPE
_NODETEMPLATE_NETWORKSETTINGS.containing_type = _NODETEMPLATE
_NODETEMPLATE_NETWORKSETTINGS_TYPE.containing_type = _NODETEMPLATE_NETWORKSETTINGS
_NODETEMPLATE.fields_by_name['resources_spec'].message_type = _RESOURCESSPEC
_NODETEMPLATE.fields_by_name['boot_disk_spec'].message_type = _DISKSPEC
_NODETEMPLATE.fields_by_name['metadata'].message_type = _NODETEMPLATE_METADATAENTRY
_NODETEMPLATE.fields_by_name['v4_address_spec'].message_type = _NODEADDRESSSPEC
_NODETEMPLATE.fields_by_name['scheduling_policy'].message_type = _SCHEDULINGPOLICY
_NODETEMPLATE.fields_by_name['network_interface_specs'].message_type = _NETWORKINTERFACESPEC
_NODETEMPLATE.fields_by_name['placement_policy'].message_type = _PLACEMENTPOLICY
_NODETEMPLATE.fields_by_name['network_settings'].message_type = _NODETEMPLATE_NETWORKSETTINGS
_NETWORKINTERFACESPEC.fields_by_name['primary_v4_address_spec'].message_type = _NODEADDRESSSPEC
_NETWORKINTERFACESPEC.fields_by_name['primary_v6_address_spec'].message_type = _NODEADDRESSSPEC
_NODEADDRESSSPEC.fields_by_name['one_to_one_nat_spec'].message_type = _ONETOONENATSPEC
_ONETOONENATSPEC.fields_by_name['ip_version'].enum_type = _IPVERSION
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.message_types_by_name['Taint'] = _TAINT
DESCRIPTOR.message_types_by_name['AttachedVolume'] = _ATTACHEDVOLUME
DESCRIPTOR.message_types_by_name['NodeTemplate'] = _NODETEMPLATE
DESCRIPTOR.message_types_by_name['NetworkInterfaceSpec'] = _NETWORKINTERFACESPEC
DESCRIPTOR.message_types_by_name['NodeAddressSpec'] = _NODEADDRESSSPEC
DESCRIPTOR.message_types_by_name['OneToOneNatSpec'] = _ONETOONENATSPEC
DESCRIPTOR.message_types_by_name['ResourcesSpec'] = _RESOURCESSPEC
DESCRIPTOR.message_types_by_name['DiskSpec'] = _DISKSPEC
DESCRIPTOR.message_types_by_name['SchedulingPolicy'] = _SCHEDULINGPOLICY
DESCRIPTOR.message_types_by_name['PlacementPolicy'] = _PLACEMENTPOLICY
DESCRIPTOR.enum_types_by_name['IpVersion'] = _IPVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {

  'KubernetesStatus' : _reflection.GeneratedProtocolMessageType('KubernetesStatus', (_message.Message,), {
    'DESCRIPTOR' : _NODE_KUBERNETESSTATUS,
    '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Node.KubernetesStatus)
    })
  ,

  'CloudStatus' : _reflection.GeneratedProtocolMessageType('CloudStatus', (_message.Message,), {
    'DESCRIPTOR' : _NODE_CLOUDSTATUS,
    '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Node.CloudStatus)
    })
  ,

  'Spec' : _reflection.GeneratedProtocolMessageType('Spec', (_message.Message,), {
    'DESCRIPTOR' : _NODE_SPEC,
    '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Node.Spec)
    })
  ,
  'DESCRIPTOR' : _NODE,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Node)
  })
_sym_db.RegisterMessage(Node)
_sym_db.RegisterMessage(Node.KubernetesStatus)
_sym_db.RegisterMessage(Node.CloudStatus)
_sym_db.RegisterMessage(Node.Spec)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

Taint = _reflection.GeneratedProtocolMessageType('Taint', (_message.Message,), {
  'DESCRIPTOR' : _TAINT,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Taint)
  })
_sym_db.RegisterMessage(Taint)

AttachedVolume = _reflection.GeneratedProtocolMessageType('AttachedVolume', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHEDVOLUME,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.AttachedVolume)
  })
_sym_db.RegisterMessage(AttachedVolume)

NodeTemplate = _reflection.GeneratedProtocolMessageType('NodeTemplate', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODETEMPLATE_METADATAENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeTemplate.MetadataEntry)
    })
  ,

  'NetworkSettings' : _reflection.GeneratedProtocolMessageType('NetworkSettings', (_message.Message,), {
    'DESCRIPTOR' : _NODETEMPLATE_NETWORKSETTINGS,
    '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings)
    })
  ,
  'DESCRIPTOR' : _NODETEMPLATE,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeTemplate)
  })
_sym_db.RegisterMessage(NodeTemplate)
_sym_db.RegisterMessage(NodeTemplate.MetadataEntry)
_sym_db.RegisterMessage(NodeTemplate.NetworkSettings)

NetworkInterfaceSpec = _reflection.GeneratedProtocolMessageType('NetworkInterfaceSpec', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKINTERFACESPEC,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NetworkInterfaceSpec)
  })
_sym_db.RegisterMessage(NetworkInterfaceSpec)

NodeAddressSpec = _reflection.GeneratedProtocolMessageType('NodeAddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _NODEADDRESSSPEC,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeAddressSpec)
  })
_sym_db.RegisterMessage(NodeAddressSpec)

OneToOneNatSpec = _reflection.GeneratedProtocolMessageType('OneToOneNatSpec', (_message.Message,), {
  'DESCRIPTOR' : _ONETOONENATSPEC,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.OneToOneNatSpec)
  })
_sym_db.RegisterMessage(OneToOneNatSpec)

ResourcesSpec = _reflection.GeneratedProtocolMessageType('ResourcesSpec', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESSPEC,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ResourcesSpec)
  })
_sym_db.RegisterMessage(ResourcesSpec)

DiskSpec = _reflection.GeneratedProtocolMessageType('DiskSpec', (_message.Message,), {
  'DESCRIPTOR' : _DISKSPEC,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.DiskSpec)
  })
_sym_db.RegisterMessage(DiskSpec)

SchedulingPolicy = _reflection.GeneratedProtocolMessageType('SchedulingPolicy', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULINGPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.SchedulingPolicy)
  })
_sym_db.RegisterMessage(SchedulingPolicy)

PlacementPolicy = _reflection.GeneratedProtocolMessageType('PlacementPolicy', (_message.Message,), {
  'DESCRIPTOR' : _PLACEMENTPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.node_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.PlacementPolicy)
  })
_sym_db.RegisterMessage(PlacementPolicy)


DESCRIPTOR._options = None
_NODETEMPLATE_METADATAENTRY._options = None
_NODETEMPLATE_NETWORKSETTINGS.fields_by_name['type']._options = None
_NODETEMPLATE.fields_by_name['metadata']._options = None
_NODETEMPLATE.fields_by_name['v4_address_spec']._options = None
_RESOURCESSPEC.fields_by_name['memory']._options = None
_RESOURCESSPEC.fields_by_name['cores']._options = None
_RESOURCESSPEC.fields_by_name['core_fraction']._options = None
_RESOURCESSPEC.fields_by_name['gpus']._options = None
_DISKSPEC.fields_by_name['disk_type_id']._options = None
_DISKSPEC.fields_by_name['disk_size']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/manager/v1/manager_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/dataproc/manager/v1/manager_service.proto',
  package='yandex.cloud.dataproc.manager.v1',
  syntax='proto3',
  serialized_options=b'\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_manager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/dataproc/manager/v1/manager_service.proto\x12 yandex.cloud.dataproc.manager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"_\n\rHbaseNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08requests\x18\x02 \x01(\x03\x12\x14\n\x0cheap_size_mb\x18\x03 \x01(\x03\x12\x18\n\x10max_heap_size_mb\x18\x04 \x01(\x03\"\xe1\x01\n\tHbaseInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x0f\n\x07regions\x18\x02 \x01(\x03\x12\x10\n\x08requests\x18\x03 \x01(\x03\x12\x14\n\x0c\x61verage_load\x18\x04 \x01(\x01\x12\x43\n\nlive_nodes\x18\x05 \x03(\x0b\x32/.yandex.cloud.dataproc.manager.v1.HbaseNodeInfo\x12\x43\n\ndead_nodes\x18\x06 \x03(\x0b\x32/.yandex.cloud.dataproc.manager.v1.HbaseNodeInfo\"r\n\x0cHDFSNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04used\x18\x02 \x01(\x03\x12\x11\n\tremaining\x18\x03 \x01(\x03\x12\x10\n\x08\x63\x61pacity\x18\x04 \x01(\x03\x12\x12\n\nnum_blocks\x18\x05 \x01(\x03\x12\r\n\x05state\x18\x06 \x01(\t\"\x89\x04\n\x08HDFSInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x19\n\x11percent_remaining\x18\x02 \x01(\x01\x12\x0c\n\x04used\x18\x03 \x01(\x03\x12\x0c\n\x04\x66ree\x18\x04 \x01(\x03\x12\x14\n\x0ctotal_blocks\x18\x05 \x01(\x03\x12\x16\n\x0emissing_blocks\x18\x06 \x01(\x03\x12\"\n\x1amissing_blocks_replica_one\x18\x07 \x01(\x03\x12\x42\n\nlive_nodes\x18\x08 \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12\x42\n\ndead_nodes\x18\t \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12\x10\n\x08safemode\x18\x0b \x01(\t\x12M\n\x15\x64\x65\x63ommissioning_nodes\x18\x0c \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12L\n\x14\x64\x65\x63ommissioned_nodes\x18\r \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12$\n\x1crequested_decommission_hosts\x18\x0e \x03(\tJ\x04\x08\n\x10\x0b\"\x9b\x01\n\x08HiveInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x19\n\x11queries_succeeded\x18\x02 \x01(\x03\x12\x16\n\x0equeries_failed\x18\x03 \x01(\x03\x12\x19\n\x11queries_executing\x18\x04 \x01(\x03\x12\x15\n\rsessions_open\x18\x05 \x01(\x03\x12\x17\n\x0fsessions_active\x18\x06 \x01(\x03\"\x8d\x01\n\x0cYarnNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x16\n\x0enum_containers\x18\x03 \x01(\x03\x12\x16\n\x0eused_memory_mb\x18\x04 \x01(\x03\x12\x1b\n\x13\x61vailable_memory_mb\x18\x05 \x01(\x03\x12\x13\n\x0bupdate_time\x18\x06 \x01(\x03\"\x87\x01\n\x08YarnInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x42\n\nlive_nodes\x18\x02 \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.YarnNodeInfo\x12$\n\x1crequested_decommission_hosts\x18\x03 \x03(\t\"\x1e\n\rZookeeperInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"\x1a\n\tOozieInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"\x19\n\x08LivyInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"\xc0\x03\n\x04Info\x12\x38\n\x04hdfs\x18\x01 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.HDFSInfo\x12\x38\n\x04yarn\x18\x02 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.YarnInfo\x12\x38\n\x04hive\x18\x03 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.HiveInfo\x12\x42\n\tzookeeper\x18\x04 \x01(\x0b\x32/.yandex.cloud.dataproc.manager.v1.ZookeeperInfo\x12:\n\x05hbase\x18\x05 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.HbaseInfo\x12:\n\x05oozie\x18\x06 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.OozieInfo\x12\x14\n\x0creport_count\x18\x07 \x01(\x03\x12\x38\n\x04livy\x18\x08 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.LivyInfo\"\x9f\x01\n\rReportRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x19\n\x11topology_revision\x18\x02 \x01(\x03\x12\x34\n\x04info\x18\x03 \x01(\x0b\x32&.yandex.cloud.dataproc.manager.v1.Info\x12\x30\n\x0c\x63ollected_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"s\n\x0bReportReply\x12\x1c\n\x14\x64\x65\x63ommission_timeout\x18\x01 \x01(\x03\x12\"\n\x1ayarn_hosts_to_decommission\x18\x02 \x03(\t\x12\"\n\x1ahdfs_hosts_to_decommission\x18\x03 \x03(\t2\x84\x01\n\x16\x44\x61taprocManagerService\x12j\n\x06Report\x12/.yandex.cloud.dataproc.manager.v1.ReportRequest\x1a-.yandex.cloud.dataproc.manager.v1.ReportReply\"\x00\x42}\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_managerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_HBASENODEINFO = _descriptor.Descriptor(
  name='HbaseNodeInfo',
  full_name='yandex.cloud.dataproc.manager.v1.HbaseNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.manager.v1.HbaseNodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requests', full_name='yandex.cloud.dataproc.manager.v1.HbaseNodeInfo.requests', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heap_size_mb', full_name='yandex.cloud.dataproc.manager.v1.HbaseNodeInfo.heap_size_mb', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_heap_size_mb', full_name='yandex.cloud.dataproc.manager.v1.HbaseNodeInfo.max_heap_size_mb', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=220,
)


_HBASEINFO = _descriptor.Descriptor(
  name='HbaseInfo',
  full_name='yandex.cloud.dataproc.manager.v1.HbaseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='available', full_name='yandex.cloud.dataproc.manager.v1.HbaseInfo.available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regions', full_name='yandex.cloud.dataproc.manager.v1.HbaseInfo.regions', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requests', full_name='yandex.cloud.dataproc.manager.v1.HbaseInfo.requests', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_load', full_name='yandex.cloud.dataproc.manager.v1.HbaseInfo.average_load', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='live_nodes', full_name='yandex.cloud.dataproc.manager.v1.HbaseInfo.live_nodes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dead_nodes', full_name='yandex.cloud.dataproc.manager.v1.HbaseInfo.dead_nodes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=448,
)


_HDFSNODEINFO = _descriptor.Descriptor(
  name='HDFSNodeInfo',
  full_name='yandex.cloud.dataproc.manager.v1.HDFSNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.manager.v1.HDFSNodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used', full_name='yandex.cloud.dataproc.manager.v1.HDFSNodeInfo.used', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remaining', full_name='yandex.cloud.dataproc.manager.v1.HDFSNodeInfo.remaining', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capacity', full_name='yandex.cloud.dataproc.manager.v1.HDFSNodeInfo.capacity', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_blocks', full_name='yandex.cloud.dataproc.manager.v1.HDFSNodeInfo.num_blocks', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='yandex.cloud.dataproc.manager.v1.HDFSNodeInfo.state', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=564,
)


_HDFSINFO = _descriptor.Descriptor(
  name='HDFSInfo',
  full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='available', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent_remaining', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.percent_remaining', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.used', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.free', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_blocks', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.total_blocks', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_blocks', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.missing_blocks', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_blocks_replica_one', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.missing_blocks_replica_one', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='live_nodes', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.live_nodes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dead_nodes', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.dead_nodes', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safemode', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.safemode', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decommissioning_nodes', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.decommissioning_nodes', index=10,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decommissioned_nodes', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.decommissioned_nodes', index=11,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_decommission_hosts', full_name='yandex.cloud.dataproc.manager.v1.HDFSInfo.requested_decommission_hosts', index=12,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=1088,
)


_HIVEINFO = _descriptor.Descriptor(
  name='HiveInfo',
  full_name='yandex.cloud.dataproc.manager.v1.HiveInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='available', full_name='yandex.cloud.dataproc.manager.v1.HiveInfo.available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queries_succeeded', full_name='yandex.cloud.dataproc.manager.v1.HiveInfo.queries_succeeded', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queries_failed', full_name='yandex.cloud.dataproc.manager.v1.HiveInfo.queries_failed', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queries_executing', full_name='yandex.cloud.dataproc.manager.v1.HiveInfo.queries_executing', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions_open', full_name='yandex.cloud.dataproc.manager.v1.HiveInfo.sessions_open', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions_active', full_name='yandex.cloud.dataproc.manager.v1.HiveInfo.sessions_active', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1246,
)


_YARNNODEINFO = _descriptor.Descriptor(
  name='YarnNodeInfo',
  full_name='yandex.cloud.dataproc.manager.v1.YarnNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.manager.v1.YarnNodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='yandex.cloud.dataproc.manager.v1.YarnNodeInfo.state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_containers', full_name='yandex.cloud.dataproc.manager.v1.YarnNodeInfo.num_containers', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used_memory_mb', full_name='yandex.cloud.dataproc.manager.v1.YarnNodeInfo.used_memory_mb', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_memory_mb', full_name='yandex.cloud.dataproc.manager.v1.YarnNodeInfo.available_memory_mb', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='yandex.cloud.dataproc.manager.v1.YarnNodeInfo.update_time', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1390,
)


_YARNINFO = _descriptor.Descriptor(
  name='YarnInfo',
  full_name='yandex.cloud.dataproc.manager.v1.YarnInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='available', full_name='yandex.cloud.dataproc.manager.v1.YarnInfo.available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='live_nodes', full_name='yandex.cloud.dataproc.manager.v1.YarnInfo.live_nodes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_decommission_hosts', full_name='yandex.cloud.dataproc.manager.v1.YarnInfo.requested_decommission_hosts', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1528,
)


_ZOOKEEPERINFO = _descriptor.Descriptor(
  name='ZookeeperInfo',
  full_name='yandex.cloud.dataproc.manager.v1.ZookeeperInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alive', full_name='yandex.cloud.dataproc.manager.v1.ZookeeperInfo.alive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1530,
  serialized_end=1560,
)


_OOZIEINFO = _descriptor.Descriptor(
  name='OozieInfo',
  full_name='yandex.cloud.dataproc.manager.v1.OozieInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alive', full_name='yandex.cloud.dataproc.manager.v1.OozieInfo.alive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1588,
)


_LIVYINFO = _descriptor.Descriptor(
  name='LivyInfo',
  full_name='yandex.cloud.dataproc.manager.v1.LivyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alive', full_name='yandex.cloud.dataproc.manager.v1.LivyInfo.alive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1590,
  serialized_end=1615,
)


_INFO = _descriptor.Descriptor(
  name='Info',
  full_name='yandex.cloud.dataproc.manager.v1.Info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hdfs', full_name='yandex.cloud.dataproc.manager.v1.Info.hdfs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yarn', full_name='yandex.cloud.dataproc.manager.v1.Info.yarn', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hive', full_name='yandex.cloud.dataproc.manager.v1.Info.hive', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zookeeper', full_name='yandex.cloud.dataproc.manager.v1.Info.zookeeper', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hbase', full_name='yandex.cloud.dataproc.manager.v1.Info.hbase', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oozie', full_name='yandex.cloud.dataproc.manager.v1.Info.oozie', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_count', full_name='yandex.cloud.dataproc.manager.v1.Info.report_count', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='livy', full_name='yandex.cloud.dataproc.manager.v1.Info.livy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1618,
  serialized_end=2066,
)


_REPORTREQUEST = _descriptor.Descriptor(
  name='ReportRequest',
  full_name='yandex.cloud.dataproc.manager.v1.ReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='yandex.cloud.dataproc.manager.v1.ReportRequest.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topology_revision', full_name='yandex.cloud.dataproc.manager.v1.ReportRequest.topology_revision', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='yandex.cloud.dataproc.manager.v1.ReportRequest.info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collected_at', full_name='yandex.cloud.dataproc.manager.v1.ReportRequest.collected_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2069,
  serialized_end=2228,
)


_REPORTREPLY = _descriptor.Descriptor(
  name='ReportReply',
  full_name='yandex.cloud.dataproc.manager.v1.ReportReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='decommission_timeout', full_name='yandex.cloud.dataproc.manager.v1.ReportReply.decommission_timeout', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yarn_hosts_to_decommission', full_name='yandex.cloud.dataproc.manager.v1.ReportReply.yarn_hosts_to_decommission', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hdfs_hosts_to_decommission', full_name='yandex.cloud.dataproc.manager.v1.ReportReply.hdfs_hosts_to_decommission', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2230,
  serialized_end=2345,
)

_HBASEINFO.fields_by_name['live_nodes'].message_type = _HBASENODEINFO
_HBASEINFO.fields_by_name['dead_nodes'].message_type = _HBASENODEINFO
_HDFSINFO.fields_by_name['live_nodes'].message_type = _HDFSNODEINFO
_HDFSINFO.fields_by_name['dead_nodes'].message_type = _HDFSNODEINFO
_HDFSINFO.fields_by_name['decommissioning_nodes'].message_type = _HDFSNODEINFO
_HDFSINFO.fields_by_name['decommissioned_nodes'].message_type = _HDFSNODEINFO
_YARNINFO.fields_by_name['live_nodes'].message_type = _YARNNODEINFO
_INFO.fields_by_name['hdfs'].message_type = _HDFSINFO
_INFO.fields_by_name['yarn'].message_type = _YARNINFO
_INFO.fields_by_name['hive'].message_type = _HIVEINFO
_INFO.fields_by_name['zookeeper'].message_type = _ZOOKEEPERINFO
_INFO.fields_by_name['hbase'].message_type = _HBASEINFO
_INFO.fields_by_name['oozie'].message_type = _OOZIEINFO
_INFO.fields_by_name['livy'].message_type = _LIVYINFO
_REPORTREQUEST.fields_by_name['info'].message_type = _INFO
_REPORTREQUEST.fields_by_name['collected_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['HbaseNodeInfo'] = _HBASENODEINFO
DESCRIPTOR.message_types_by_name['HbaseInfo'] = _HBASEINFO
DESCRIPTOR.message_types_by_name['HDFSNodeInfo'] = _HDFSNODEINFO
DESCRIPTOR.message_types_by_name['HDFSInfo'] = _HDFSINFO
DESCRIPTOR.message_types_by_name['HiveInfo'] = _HIVEINFO
DESCRIPTOR.message_types_by_name['YarnNodeInfo'] = _YARNNODEINFO
DESCRIPTOR.message_types_by_name['YarnInfo'] = _YARNINFO
DESCRIPTOR.message_types_by_name['ZookeeperInfo'] = _ZOOKEEPERINFO
DESCRIPTOR.message_types_by_name['OozieInfo'] = _OOZIEINFO
DESCRIPTOR.message_types_by_name['LivyInfo'] = _LIVYINFO
DESCRIPTOR.message_types_by_name['Info'] = _INFO
DESCRIPTOR.message_types_by_name['ReportRequest'] = _REPORTREQUEST
DESCRIPTOR.message_types_by_name['ReportReply'] = _REPORTREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HbaseNodeInfo = _reflection.GeneratedProtocolMessageType('HbaseNodeInfo', (_message.Message,), {
  'DESCRIPTOR' : _HBASENODEINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HbaseNodeInfo)
  })
_sym_db.RegisterMessage(HbaseNodeInfo)

HbaseInfo = _reflection.GeneratedProtocolMessageType('HbaseInfo', (_message.Message,), {
  'DESCRIPTOR' : _HBASEINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HbaseInfo)
  })
_sym_db.RegisterMessage(HbaseInfo)

HDFSNodeInfo = _reflection.GeneratedProtocolMessageType('HDFSNodeInfo', (_message.Message,), {
  'DESCRIPTOR' : _HDFSNODEINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HDFSNodeInfo)
  })
_sym_db.RegisterMessage(HDFSNodeInfo)

HDFSInfo = _reflection.GeneratedProtocolMessageType('HDFSInfo', (_message.Message,), {
  'DESCRIPTOR' : _HDFSINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HDFSInfo)
  })
_sym_db.RegisterMessage(HDFSInfo)

HiveInfo = _reflection.GeneratedProtocolMessageType('HiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _HIVEINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HiveInfo)
  })
_sym_db.RegisterMessage(HiveInfo)

YarnNodeInfo = _reflection.GeneratedProtocolMessageType('YarnNodeInfo', (_message.Message,), {
  'DESCRIPTOR' : _YARNNODEINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.YarnNodeInfo)
  })
_sym_db.RegisterMessage(YarnNodeInfo)

YarnInfo = _reflection.GeneratedProtocolMessageType('YarnInfo', (_message.Message,), {
  'DESCRIPTOR' : _YARNINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.YarnInfo)
  })
_sym_db.RegisterMessage(YarnInfo)

ZookeeperInfo = _reflection.GeneratedProtocolMessageType('ZookeeperInfo', (_message.Message,), {
  'DESCRIPTOR' : _ZOOKEEPERINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.ZookeeperInfo)
  })
_sym_db.RegisterMessage(ZookeeperInfo)

OozieInfo = _reflection.GeneratedProtocolMessageType('OozieInfo', (_message.Message,), {
  'DESCRIPTOR' : _OOZIEINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.OozieInfo)
  })
_sym_db.RegisterMessage(OozieInfo)

LivyInfo = _reflection.GeneratedProtocolMessageType('LivyInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIVYINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.LivyInfo)
  })
_sym_db.RegisterMessage(LivyInfo)

Info = _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {
  'DESCRIPTOR' : _INFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.Info)
  })
_sym_db.RegisterMessage(Info)

ReportRequest = _reflection.GeneratedProtocolMessageType('ReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTREQUEST,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.ReportRequest)
  })
_sym_db.RegisterMessage(ReportRequest)

ReportReply = _reflection.GeneratedProtocolMessageType('ReportReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTREPLY,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.manager_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.ReportReply)
  })
_sym_db.RegisterMessage(ReportReply)


DESCRIPTOR._options = None

_DATAPROCMANAGERSERVICE = _descriptor.ServiceDescriptor(
  name='DataprocManagerService',
  full_name='yandex.cloud.dataproc.manager.v1.DataprocManagerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2348,
  serialized_end=2480,
  methods=[
  _descriptor.MethodDescriptor(
    name='Report',
    full_name='yandex.cloud.dataproc.manager.v1.DataprocManagerService.Report',
    index=0,
    containing_service=None,
    input_type=_REPORTREQUEST,
    output_type=_REPORTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPROCMANAGERSERVICE)

DESCRIPTOR.services_by_name['DataprocManagerService'] = _DATAPROCMANAGERSERVICE

# @@protoc_insertion_point(module_scope)
